@@ -1,12 +1,14 @@
 from abc import abstractmethod
 from typing import Optional
 
+from pydantic import Field
+
 from datahub.api.entities.assertion.assertion_trigger import AssertionTrigger
-from datahub.configuration.pydantic_migration_helpers import v1_ConfigModel, v1_Field
+from datahub.configuration.common import ConfigModel
 from datahub.metadata.com.linkedin.pegasus2avro.assertion import AssertionInfo
 
 
-class BaseAssertionProtocol(v1_ConfigModel):
+class BaseAssertionProtocol(ConfigModel):
     @abstractmethod
     def get_id(self) -> str:
         pass
@@ -24,15 +26,15 @@ class BaseAssertionProtocol(v1_ConfigModel):
         pass
 
 
-class BaseAssertion(v1_ConfigModel):
-    id_raw: Optional[str] = v1_Field(
+class BaseAssertion(ConfigModel):
+    id_raw: Optional[str] = Field(
         default=None,
         description="The raw id of the assertion."
         "If provided, this is used when creating identifier for this assertion"
         "along with assertion type and entity.",
     )
 
-    id: Optional[str] = v1_Field(
+    id: Optional[str] = Field(
         default=None,
         description="The id of the assertion."
         "If provided, this is used as identifier for this assertion."
@@ -41,17 +43,14 @@ class BaseAssertion(v1_ConfigModel):
 
     description: Optional[str] = None
 
-    # Can contain metadata extracted from datahub. e.g.
-    # - entity qualified name
-    # - entity schema
     meta: Optional[dict] = None
 
 
 class BaseEntityAssertion(BaseAssertion):
-    entity: str = v1_Field(
+    entity: str = Field(
         description="The entity urn that the assertion is associated with"
     )
 
-    trigger: Optional[AssertionTrigger] = v1_Field(
-        description="The trigger schedule for assertion", alias="schedule"
+    trigger: Optional[AssertionTrigger] = Field(
+        default=None, description="The trigger schedule for assertion", alias="schedule"
     )
