@@ -2,31 +2,29 @@ from datetime import timedelta
 from typing import Union
 
 import humanfriendly
+from pydantic import Field, RootModel, field_validator
 from typing_extensions import Literal
 
-from datahub.configuration.pydantic_migration_helpers import (
-    v1_ConfigModel,
-    v1_Field,
-    v1_validator,
-)
+from datahub.configuration.common import ConfigModel
 
 
-class CronTrigger(v1_ConfigModel):
+class CronTrigger(ConfigModel):
     type: Literal["cron"]
-    cron: str = v1_Field(
+    cron: str = Field(
         description="The cron expression to use. See https://crontab.guru/ for help."
     )
-    timezone: str = v1_Field(
+    timezone: str = Field(
         "UTC",
         description="The timezone to use for the cron schedule. Defaults to UTC.",
     )
 
 
-class IntervalTrigger(v1_ConfigModel):
+class IntervalTrigger(ConfigModel):
     type: Literal["interval"]
     interval: timedelta
 
-    @v1_validator("interval", pre=True)
+    @field_validator("interval", mode="before")
+    @classmethod
     def lookback_interval_to_timedelta(cls, v):
         if isinstance(v, str):
             seconds = humanfriendly.parse_timespan(v)
@@ -34,19 +32,21 @@ class IntervalTrigger(v1_ConfigModel):
         raise ValueError("Invalid value.")
 
 
-class EntityChangeTrigger(v1_ConfigModel):
+class EntityChangeTrigger(ConfigModel):
     type: Literal["on_table_change"]
 
 
-class ManualTrigger(v1_ConfigModel):
+class ManualTrigger(ConfigModel):
     type: Literal["manual"]
 
 
-class AssertionTrigger(v1_ConfigModel):
-    __root__: Union[
-        CronTrigger, IntervalTrigger, EntityChangeTrigger, ManualTrigger
-    ] = v1_Field(discriminator="type")
+class AssertionTrigger(
+    RootModel[Union[CronTrigger, IntervalTrigger, EntityChangeTrigger, ManualTrigger]]
+):
+    root: Union[CronTrigger, IntervalTrigger, EntityChangeTrigger, ManualTrigger] = (
+        Field(discriminator="type")
+    )
 
     @property
     def trigger(self):
-        return self.__root__
+        return self.root
