@@ -3,7 +3,7 @@ import logging
 from typing import Dict, Optional, Type, TypeVar, Union
 
 from avrogen.dict_wrapper import DictWrapper
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 import datahub.metadata.schema_classes as models
 from datahub.metadata.schema_classes import __SCHEMA_TYPES as SCHEMA_TYPES
@@ -17,8 +17,7 @@ T = TypeVar("T", bound=BaseModel)
 
 
 class SerializedResourceValue(BaseModel):
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
     content_type: str
     blob: bytes
@@ -104,7 +103,7 @@ class SerializedResourceValue(BaseModel):
             assert self.schema_ref
             assert self.schema_ref == model_type.__name__
         object_dict = self.as_raw_json()
-        return model_type.parse_obj(object_dict)
+        return model_type.model_validate(object_dict)
 
     @classmethod
     def from_resource_value(
@@ -131,7 +130,7 @@ class SerializedResourceValue(BaseModel):
         elif isinstance(object, BaseModel):
             return SerializedResourceValue(
                 content_type=models.SerializedValueContentTypeClass.JSON,
-                blob=json.dumps(object.dict(), sort_keys=True).encode("utf-8"),
+                blob=json.dumps(object.model_dump(), sort_keys=True).encode("utf-8"),
                 schema_type=models.SerializedValueSchemaTypeClass.JSON,
                 schema_ref=object.__class__.__name__,
             )
