@@ -114,7 +114,7 @@ def load_client_config() -> DatahubClientConfig:
     try:
         _ensure_datahub_config()
         client_config_dict = get_raw_client_config()
-        datahub_config: DatahubClientConfig = DatahubConfig.parse_obj(
+        datahub_config: DatahubClientConfig = DatahubConfig.model_validate(
             client_config_dict
         ).gms
         return datahub_config
@@ -146,7 +146,7 @@ def write_gms_config(
             logger.debug(
                 f"Failed to retrieve config from file {DATAHUB_CONFIG_PATH}: {e}. This isn't fatal."
             )
-        config_dict = {**previous_config, **config.dict()}
+        config_dict = {**previous_config, **config.model_dump()}
     else:
-        config_dict = config.dict()
+        config_dict = config.model_dump()
     persist_raw_datahub_config(config_dict)
