@@ -1,3 +1,4 @@
+import contextvars
 import dataclasses
 import re
 import unittest.mock
@@ -21,12 +22,12 @@ from typing import (
 import pydantic
 import pydantic_core
 from cached_property import cached_property
-from pydantic import BaseModel, Extra, ValidationError
+from pydantic import BaseModel, ConfigDict, SecretStr, ValidationError, model_validator
 from pydantic.fields import Field
 from typing_extensions import Protocol, Self
 
 from datahub.configuration._config_enum import ConfigEnum as ConfigEnum
-from datahub.configuration.pydantic_migration_helpers import PYDANTIC_VERSION_2
+from datahub.masking.secret_registry import SecretRegistry, is_masking_enabled
 from datahub.utilities.dedup_list import deduplicate_list
 
 REDACT_KEYS = {
@@ -96,6 +97,11 @@ else:
 
 LaxStr = Annotated[str, pydantic.BeforeValidator(lambda v: str(v))]
 
+# Context variable to track if we're inside a nested ConfigModel construction
+_inside_nested_config: contextvars.ContextVar[bool] = contextvars.ContextVar(
+    "_inside_nested_config", default=False
+)
+
 
 @dataclasses.dataclass(frozen=True)
 class SupportedSources:
@@ -111,49 +117,133 @@ class SupportedSources:
         return json_schema
 
 
+def _config_model_schema_extra(schema: Dict[str, Any], model: Type[BaseModel]) -> None:
+    # We use the custom "hidden_from_docs" attribute to hide fields from the
+    # autogenerated docs.
+    remove_fields = []
+    for key, prop in schema.get("properties", {}).items():
+        if prop.get("hidden_from_docs"):
+            remove_fields.append(key)
+
+    for key in remove_fields:
+        del schema["properties"][key]
+
+
 class ConfigModel(BaseModel):
-    class Config:
-        @staticmethod
-        def _schema_extra(schema: Dict[str, Any], model: Type["ConfigModel"]) -> None:
-            # We use the custom "hidden_from_docs" attribute to hide fields from the
-            # autogenerated docs.
-            remove_fields = []
-            for key, prop in schema.get("properties", {}).items():
-                if prop.get("hidden_from_docs"):
-                    remove_fields.append(key)
+    model_config = ConfigDict(
+        extra="forbid",
+        ignored_types=(cached_property,),
+        json_schema_extra=_config_model_schema_extra,
+    )
 
-            for key in remove_fields:
-                del schema["properties"][key]
+    @model_validator(mode="wrap")
+    @classmethod
+    def _track_nesting_context(
+        cls,
+        data: Any,
+        handler: pydantic.ValidatorFunctionWrapHandler,
+        info: pydantic.ValidationInfo,
+    ) -> Self:
+        """
+        Wrap validator that tracks nesting context for nested ConfigModel detection.
 
-        # This is purely to suppress pydantic's warnings, since this class is used everywhere.
-        if PYDANTIC_VERSION_2:
-            extra = "forbid"
-            ignored_types = (cached_property,)
-            json_schema_extra = _schema_extra
-        else:
-            extra = Extra.forbid
-            underscore_attrs_are_private = True
-            keep_untouched = (
-                cached_property,
-            )  # needed to allow cached_property to work. See https://github.com/samuelcolvin/pydantic/issues/1241 for more info.
-            schema_extra = _schema_extra
+        Sets a context variable so nested ConfigModels know they're being constructed as fields.
+        """
+        # Set context for any nested models that will be created during field processing
+        token = _inside_nested_config.set(True)
+        try:
+            # Process the model normally (this calls __init__ and all validators)
+            instance = handler(data)
+        finally:
+            # Reset context after processing
+            _inside_nested_config.reset(token)
+
+        return instance
+
+    @model_validator(mode="after")
+    def _register_secret_fields(self) -> Self:
+        """
+        Register SecretStr fields with the secret masking registry.
+        Recursively traverses nested ConfigModel instances to find all SecretStr fields.
+
+        Only models that are constructed outside of Pydantic field processing will register secrets.
+        This ensures we capture the full qualified paths for nested secrets.
+
+        Performance: Uses batch registration for efficiency - single version
+        increment instead of one per secret.
+        """
+        if not is_masking_enabled():
+            return self
+
+        # Only register if we're NOT inside another ConfigModel's field processing
+        # This means we're a "root" model from the user's perspective
+        if _inside_nested_config.get():
+            return self
+
+        # Collect all secrets recursively (including from nested models)
+        secrets: Dict[str, str] = {}
+        self._collect_secrets(secrets, prefix="")
+
+        # Batch register all secrets in one operation
+        if secrets:
+            SecretRegistry.get_instance().register_secrets_batch(secrets)
+
+        return self
+
+    def _collect_secrets(self, secrets: Dict[str, str], prefix: str) -> None:
+        """
+        Recursively collect SecretStr fields from this model and nested ConfigModel instances.
+
+        Args:
+            secrets: Dictionary to populate with field_name -> secret_value mappings
+            prefix: Prefix for nested field names (e.g., "azure_auth." for nested fields)
+        """
+        for field_name, _field_info in self.__class__.model_fields.items():
+            field_value = getattr(self, field_name, None)
+
+            if field_value is None:
+                continue
+
+            # Build the full field path for better debugging
+            full_name = f"{prefix}{field_name}" if prefix else field_name
+
+            if isinstance(field_value, SecretStr):
+                # Direct SecretStr field
+                secret_value = field_value.get_secret_value()
+                if secret_value:
+                    secrets[full_name] = secret_value
+            elif isinstance(field_value, ConfigModel):
+                # Nested ConfigModel - recurse into it
+                field_value._collect_secrets(secrets, prefix=f"{full_name}.")
+            elif isinstance(field_value, list):
+                # Handle lists of ConfigModels
+                for idx, item in enumerate(field_value):
+                    if isinstance(item, ConfigModel):
+                        item._collect_secrets(secrets, prefix=f"{full_name}[{idx}].")
+            elif isinstance(field_value, dict):
+                # Handle dicts with ConfigModel values
+                for key, item in field_value.items():
+                    if isinstance(item, ConfigModel):
+                        item._collect_secrets(secrets, prefix=f"{full_name}[{key}].")
 
     @classmethod
     def parse_obj_allow_extras(cls, obj: Any) -> Self:
-        if PYDANTIC_VERSION_2:
-            try:
-                with unittest.mock.patch.dict(
-                    cls.model_config,  # type: ignore
-                    {"extra": "allow"},
-                    clear=False,
-                ):
-                    cls.model_rebuild(force=True)  # type: ignore
-                    return cls.parse_obj(obj)
-            finally:
+        """Parse an object while allowing extra fields.
+
+        This method temporarily modifies the model's configuration to allow extra fields.
+
+        TODO: Do we really need to support this behaviour? Consider removing this method in future.
+        """
+        try:
+            with unittest.mock.patch.dict(
+                cls.model_config,  # type: ignore
+                {"extra": "allow"},
+                clear=False,
+            ):
                 cls.model_rebuild(force=True)  # type: ignore
-        else:
-            with unittest.mock.patch.object(cls.Config, "extra", pydantic.Extra.allow):
-                return cls.parse_obj(obj)
+                return cls.model_validate(obj)
+        finally:
+            cls.model_rebuild(force=True)  # type: ignore
 
 
 class PermissiveConfigModel(ConfigModel):
@@ -162,22 +252,13 @@ class PermissiveConfigModel(ConfigModel):
     # but still allow the user to pass in arbitrary fields that we don't care about.
     # It is usually used for argument bags that are passed through to third-party libraries.
 
-    class Config:
-        if PYDANTIC_VERSION_2:  # noqa: SIM108
-            extra = "allow"
-        else:
-            extra = Extra.allow
+    model_config = ConfigDict(extra="allow")
 
 
 class ConnectionModel(BaseModel):
     """Represents the config associated with a connection"""
 
-    class Config:
-        if PYDANTIC_VERSION_2:
-            extra = "allow"
-        else:
-            extra = Extra.allow
-            underscore_attrs_are_private = True
+    model_config = ConfigDict(extra="allow")
 
 
 class TransformerSemantics(ConfigEnum):
