@@ -21,13 +21,10 @@ from urllib.parse import urlparse
 
 import botocore.exceptions
 import yaml
-from pydantic import validator
+from pydantic import field_validator
 from pydantic.fields import Field
 
 from datahub.api.entities.dataset.dataset import Dataset
-from datahub.api.entities.external.external_entities import (
-    PlatformResourceRepository,
-)
 from datahub.api.entities.external.lake_formation_external_entites import (
     LakeFormationTag,
 )
@@ -63,13 +60,15 @@ from datahub.ingestion.api.source import MetadataWorkUnitProcessor
 from datahub.ingestion.api.workunit import MetadataWorkUnit
 from datahub.ingestion.source.aws import s3_util
 from datahub.ingestion.source.aws.aws_common import AwsSourceConfig
+from datahub.ingestion.source.aws.platform_resource_repository import (
+    GluePlatformResourceRepository,
+)
 from datahub.ingestion.source.aws.s3_util import (
     is_s3_uri,
     make_s3_urn,
     make_s3_urn_for_lineage,
 )
 from datahub.ingestion.source.aws.tag_entities import (
-    LakeFormationTagPlatformResource,
     LakeFormationTagPlatformResourceId,
 )
 from datahub.ingestion.source.common.subtypes import (
@@ -222,7 +221,8 @@ class GlueSourceConfig(
     def lakeformation_client(self):
         return self.get_lakeformation_client()
 
-    @validator("glue_s3_lineage_direction")
+    @field_validator("glue_s3_lineage_direction", mode="after")
+    @classmethod
     def check_direction(cls, v: str) -> str:
         if v.lower() not in ["upstream", "downstream"]:
             raise ValueError(
@@ -230,7 +230,8 @@ class GlueSourceConfig(
             )
         return v.lower()
 
-    @validator("platform")
+    @field_validator("platform", mode="after")
+    @classmethod
     def platform_validator(cls, v: str) -> str:
         if not v or v in VALID_PLATFORMS:
             return v
@@ -336,6 +337,26 @@ class GlueSource(StatefulIngestionSourceBase):
     }
     ```
 
+    ### Glue Cross-account Access
+
+    Glue ingestion supports cross-account access and lineage by allowing you to specify the target AWS account's Glue catalog using the `catalog_id` parameter in the ingestion recipe.
+    This enables ingestion of Glue metadata from different AWS accounts, supporting cross-account lineage scenarios.
+    You must ensure the correct IAM roles and permissions are set up for cross-account access.
+
+    Example: There are 2 AWS accounts A and B, A has shared metadata with B. Account A has Glue table - tableA.
+    If you ingest account A using Glue it will create dataset tableA in DataHub.
+    If you want to ingest tableA via account B you can pass `catalog_id` parameter in recipe with A's catalog id.
+
+    **Ingestion without platform instance parameter**
+    - If both catalogs are ingested without platform instance parameter, DataHub should be able to understand that the database and tables are same
+    - DataHub will create single entity for table tableA
+    - It should show lineage between Glue and S3.
+      You have to ingest S3 as separate source (https://docs.datahub.com/docs/generated/ingestion/sources/s3)
+
+    **Ingestion with platform instance parameter**
+    - It will create separate entities for tableA as it will have different URN path
+    - It should show lineage between Glue and S3
+
     """
 
     source_config: GlueSourceConfig
@@ -357,10 +378,14 @@ class GlueSource(StatefulIngestionSourceBase):
         self.extract_transforms = config.extract_transforms
         self.env = config.env
 
-        self.platform_resource_repository: Optional[PlatformResourceRepository] = None
+        self.platform_resource_repository: Optional[
+            "GluePlatformResourceRepository"
+        ] = None
         if self.ctx.graph:
-            self.platform_resource_repository = PlatformResourceRepository(
-                self.ctx.graph
+            self.platform_resource_repository = GluePlatformResourceRepository(
+                self.ctx.graph,
+                platform_instance=self.source_config.platform_instance,
+                catalog=self.source_config.catalog_id,
             )
 
     def get_database_lf_tags(
@@ -395,7 +420,7 @@ class GlueSource(StatefulIngestionSourceBase):
                     t = LakeFormationTag(
                         key=tag_key,
                         value=tag_value,
-                        catalog_id=catalog_id,
+                        catalog=catalog_id,
                     )
                     tags.append(t)
             return tags
@@ -438,7 +463,7 @@ class GlueSource(StatefulIngestionSourceBase):
                     t = LakeFormationTag(
                         key=tag_key,
                         value=tag_value,
-                        catalog_id=catalog_id,
+                        catalog=catalog_id,
                     )
                     tags.append(t)
             return tags
@@ -470,7 +495,7 @@ class GlueSource(StatefulIngestionSourceBase):
 
     @classmethod
     def create(cls, config_dict, ctx):
-        config = GlueSourceConfig.parse_obj(config_dict)
+        config = GlueSourceConfig.model_validate(config_dict)
         return cls(config, ctx)
 
     @property
@@ -522,6 +547,14 @@ class GlueSource(StatefulIngestionSourceBase):
         bucket = url.netloc
         key = url.path[1:]
 
+        # validate that we have a non-empty key
+        if not key:
+            self.report.num_job_script_location_invalid += 1
+            logger.warning(
+                f"Error parsing DAG for Glue job. The script {script_path} is not a valid S3 path for flow urn: {flow_urn}."
+            )
+            return None
+
         # download the script contents
         # see https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3.html#S3.Client.get_object
         try:
@@ -533,6 +566,14 @@ class GlueSource(StatefulIngestionSourceBase):
             )
             self.report.num_job_script_failed_download += 1
             return None
+        except botocore.exceptions.ParamValidationError as e:
+            self.report_warning(
+                flow_urn,
+                f"Invalid S3 path for Glue job script {script_path}: {e}",
+            )
+            self.report.num_job_script_location_invalid += 1
+            return None
+
         script = obj["Body"].read().decode("utf-8")
 
         try:
@@ -1163,16 +1204,17 @@ class GlueSource(StatefulIngestionSourceBase):
         self, tag: LakeFormationTag
     ) -> Iterable[MetadataWorkUnit]:
         if self.ctx.graph and self.platform_resource_repository:
-            platform_resource_id = LakeFormationTagPlatformResourceId.from_tag(
-                platform_instance=self.source_config.platform_instance,
-                platform_resource_repository=self.platform_resource_repository,
-                catalog=tag.catalog,
-                tag=tag,
+            platform_resource_id = (
+                LakeFormationTagPlatformResourceId.get_or_create_from_tag(
+                    tag=tag,
+                    platform_resource_repository=self.platform_resource_repository,
+                    catalog_id=tag.catalog,
+                )
             )
             logger.info(f"Created platform resource {platform_resource_id}")
 
-            lf_tag = LakeFormationTagPlatformResource.get_from_datahub(
-                platform_resource_id, self.platform_resource_repository, False
+            lf_tag = self.platform_resource_repository.get_entity_from_datahub(
+                platform_resource_id, False
             )
             if (
                 tag.to_datahub_tag_urn().urn()
