@@ -1,8 +1,8 @@
 import json
 import tempfile
-from typing import Any, Dict, Optional
+from typing import Dict, Optional
 
-from pydantic import Field, root_validator
+from pydantic import Field, model_validator
 
 from datahub.configuration import ConfigModel
 from datahub.configuration.validate_multiline_string import pydantic_multiline_string
@@ -37,16 +37,16 @@ class GCPCredential(ConfigModel):
 
     _fix_private_key_newlines = pydantic_multiline_string("private_key")
 
-    @root_validator(skip_on_failure=True)
-    def validate_config(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        if values.get("client_x509_cert_url") is None:
-            values["client_x509_cert_url"] = (
-                f"https://www.googleapis.com/robot/v1/metadata/x509/{values['client_email']}"
+    @model_validator(mode="after")
+    def validate_config(self) -> "GCPCredential":
+        if self.client_x509_cert_url is None:
+            self.client_x509_cert_url = (
+                f"https://www.googleapis.com/robot/v1/metadata/x509/{self.client_email}"
             )
-        return values
+        return self
 
     def create_credential_temp_file(self, project_id: Optional[str] = None) -> str:
-        configs = self.dict()
+        configs = self.model_dump()
         if project_id:
             configs["project_id"] = project_id
         with tempfile.NamedTemporaryFile(delete=False) as fp:
@@ -55,7 +55,7 @@ class GCPCredential(ConfigModel):
             return fp.name
 
     def to_dict(self, project_id: Optional[str] = None) -> Dict[str, str]:
-        configs = self.dict()
+        configs = self.model_dump()
         if project_id:
             configs["project_id"] = project_id
         return configs
