@@ -412,7 +412,10 @@ class MongoSourceConnector(BaseConnector):
 
         # Escape topic_prefix to handle cases where it contains dots
         # Some users configure topic.prefix like "my.mongodb" which breaks the regex
-        topic_naming_pattern = rf"{re.escape(topic_prefix)}\.(\w+)\.(\w+)"
+
+        # \w is equivalent to [a-zA-Z0-9_]
+        # So [\w-]+ matches alphanumeric characters, underscores, and hyphens
+        topic_naming_pattern = rf"{re.escape(topic_prefix)}\.([\w-]+)\.([\w-]+)"
 
         if not self.connector_manifest.topic_names:
             return lineages
