@@ -177,6 +177,10 @@ class SnowflakeQuery:
         FROM {db_clause}information_schema.procedures
         order by procedure_schema, procedure_name"""
 
+    @staticmethod
+    def streamlit_apps_for_database(db_name: str) -> str:
+        return f'SHOW STREAMLITS IN DATABASE "{db_name}"'
+
     @staticmethod
     def get_all_tags():
         return """
