@@ -5,6 +5,7 @@ from datetime import datetime, timezone
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 
 import pydantic
+from pydantic import ConfigDict
 
 from datahub.configuration.time_window_config import BaseTimeWindowConfig
 from datahub.emitter.mce_builder import make_user_urn
@@ -70,8 +71,7 @@ OPERATION_STATEMENT_TYPES = {
 
 
 class PermissiveModel(pydantic.BaseModel):
-    class Config:
-        extra = "allow"
+    model_config = ConfigDict(extra="allow")
 
 
 class SnowflakeColumnReference(PermissiveModel):
