@@ -5,10 +5,10 @@ import re
 from dataclasses import dataclass, field
 from datetime import datetime
 from functools import partial
-from typing import ClassVar, Iterable, List, Optional, Union, cast
+from typing import Any, ClassVar, Iterable, List, Optional, Union, cast
 
 import smart_open
-from pydantic import BaseModel, Field, validator
+from pydantic import BaseModel, ConfigDict, Field, field_validator
 
 from datahub.configuration.common import HiddenFromDocs
 from datahub.configuration.datetimes import parse_user_datetime
@@ -227,7 +227,7 @@ class SqlQueriesSource(Source):
 
     @classmethod
     def create(cls, config_dict: dict, ctx: PipelineContext) -> "SqlQueriesSource":
-        config = SqlQueriesSourceConfig.parse_obj(config_dict)
+        config = SqlQueriesSourceConfig.model_validate(config_dict)
         return cls(ctx, config)
 
     def get_report(self) -> SqlQueriesSourceReport:
@@ -447,22 +447,24 @@ class QueryEntry(BaseModel):
     # Validation context for URN creation
     _validation_context: ClassVar[Optional[SqlQueriesSourceConfig]] = None
 
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
-    @validator("timestamp", pre=True)
-    def parse_timestamp(cls, v):
+    @field_validator("timestamp", mode="before")
+    @classmethod
+    def parse_timestamp(cls, v: Any) -> Any:
         return None if v is None else parse_user_datetime(str(v))
 
-    @validator("user", pre=True)
-    def parse_user(cls, v):
+    @field_validator("user", mode="before")
+    @classmethod
+    def parse_user(cls, v: Any) -> Any:
         if v is None:
             return None
 
         return v if isinstance(v, CorpUserUrn) else CorpUserUrn(v)
 
-    @validator("downstream_tables", "upstream_tables", pre=True)
-    def parse_tables(cls, v):
+    @field_validator("downstream_tables", "upstream_tables", mode="before")
+    @classmethod
+    def parse_tables(cls, v: Any) -> Any:
         if not v:
             return []
 
@@ -495,6 +497,6 @@ class QueryEntry(BaseModel):
         # Set validation context for URN creation
         cls._validation_context = config
         try:
-            return cls.parse_obj(entry_dict)
+            return cls.model_validate(entry_dict)
         finally:
             cls._validation_context = None
