@@ -1,14 +1,17 @@
 from __future__ import annotations
 
 from datetime import datetime
-from typing import Dict, List, Optional, Type, Union
+from typing import Dict, List, Optional, Sequence, Type, Union
 
+from deprecated.sphinx import deprecated
 from typing_extensions import Self
 
 import datahub.metadata.schema_classes as models
 from datahub.emitter.enum_helpers import get_enum_options
 from datahub.metadata.urns import ChartUrn, DatasetUrn, Urn
 from datahub.sdk._shared import (
+    ActorUrnOrStr,
+    ChangeAuditStampsMixin,
     DataPlatformInstanceUrnOrStr,
     DataPlatformUrnOrStr,
     DatasetUrnOrStr,
@@ -23,14 +26,17 @@ from datahub.sdk._shared import (
     HasTerms,
     LinksInputType,
     OwnersInputType,
+    ParentContainerInputType,
     TagsInputType,
     TermsInputType,
 )
 from datahub.sdk.dataset import Dataset
 from datahub.sdk.entity import Entity, ExtraAspectsType
+from datahub.utilities.sentinels import Unset, unset
 
 
 class Chart(
+    ChangeAuditStampsMixin,
     HasPlatformInstance,
     HasSubtype,
     HasOwnership,
@@ -67,17 +73,23 @@ class Chart(
         chart_url: Optional[str] = None,
         custom_properties: Optional[Dict[str, str]] = None,
         last_modified: Optional[datetime] = None,
+        last_modified_by: Optional[ActorUrnOrStr] = None,
+        created_at: Optional[datetime] = None,
+        created_by: Optional[ActorUrnOrStr] = None,
+        deleted_on: Optional[datetime] = None,
+        deleted_by: Optional[ActorUrnOrStr] = None,
         last_refreshed: Optional[datetime] = None,
         chart_type: Optional[Union[str, models.ChartTypeClass]] = None,
         access: Optional[str] = None,
+        input_datasets: Optional[Sequence[Union[DatasetUrnOrStr, Dataset]]] = None,
         # Standard aspects.
+        parent_container: ParentContainerInputType | Unset = unset,
         subtype: Optional[str] = None,
         owners: Optional[OwnersInputType] = None,
         links: Optional[LinksInputType] = None,
         tags: Optional[TagsInputType] = None,
         terms: Optional[TermsInputType] = None,
         domain: Optional[DomainInputType] = None,
-        input_datasets: Optional[List[Union[DatasetUrnOrStr, Dataset]]] = None,
         extra_aspects: ExtraAspectsType = None,
     ):
         """Initialize a new Chart instance."""
@@ -90,20 +102,100 @@ class Chart(
         self._set_extra_aspects(extra_aspects)
 
         self._set_platform_instance(platform, platform_instance)
+        self._ensure_chart_props(display_name=display_name)
+        self._init_chart_properties(
+            description,
+            display_name,
+            external_url,
+            chart_url,
+            custom_properties,
+            last_modified,
+            last_modified_by,
+            created_at,
+            created_by,
+            last_refreshed,
+            deleted_on,
+            deleted_by,
+            chart_type,
+            access,
+            input_datasets,
+        )
+        self._init_standard_aspects(
+            parent_container, subtype, owners, links, tags, terms, domain
+        )
 
-        # Set additional properties
+    @classmethod
+    def _new_from_graph(cls, urn: Urn, current_aspects: models.AspectBag) -> Self:
+        assert isinstance(urn, ChartUrn)
+        entity = cls(
+            platform=urn.dashboard_tool,
+            name=urn.chart_id,
+        )
+        return entity._init_from_graph(current_aspects)
+
+    def _init_chart_properties(
+        self,
+        description: Optional[str],
+        display_name: Optional[str],
+        external_url: Optional[str],
+        chart_url: Optional[str],
+        custom_properties: Optional[Dict[str, str]],
+        last_modified: Optional[datetime],
+        last_modified_by: Optional[ActorUrnOrStr],
+        created_at: Optional[datetime],
+        created_by: Optional[ActorUrnOrStr],
+        last_refreshed: Optional[datetime],
+        deleted_on: Optional[datetime],
+        deleted_by: Optional[ActorUrnOrStr],
+        chart_type: Optional[Union[str, models.ChartTypeClass]],
+        access: Optional[str],
+        input_datasets: Optional[Sequence[Union[DatasetUrnOrStr, Dataset]]],
+    ) -> None:
+        """Initialize chart-specific properties."""
+        if description is not None:
+            self.set_description(description)
+        if display_name is not None:
+            self.set_display_name(display_name)
         if external_url is not None:
             self.set_external_url(external_url)
         if chart_url is not None:
             self.set_chart_url(chart_url)
         if custom_properties is not None:
             self.set_custom_properties(custom_properties)
+        if last_modified is not None:
+            self.set_last_modified(last_modified)
+        if last_modified_by is not None:
+            self.set_last_modified_by(last_modified_by)
+        if created_at is not None:
+            self.set_created_at(created_at)
+        if created_by is not None:
+            self.set_created_by(created_by)
+        if deleted_on is not None:
+            self.set_deleted_on(deleted_on)
+        if deleted_by is not None:
+            self.set_deleted_by(deleted_by)
         if last_refreshed is not None:
             self.set_last_refreshed(last_refreshed)
         if chart_type is not None:
             self.set_chart_type(chart_type)
         if access is not None:
             self.set_access(access)
+        if input_datasets is not None:
+            self.set_input_datasets(input_datasets)
+
+    def _init_standard_aspects(
+        self,
+        parent_container: ParentContainerInputType | Unset,
+        subtype: Optional[str],
+        owners: Optional[OwnersInputType],
+        links: Optional[LinksInputType],
+        tags: Optional[TagsInputType],
+        terms: Optional[TermsInputType],
+        domain: Optional[DomainInputType],
+    ) -> None:
+        """Initialize standard aspects."""
+        if parent_container is not unset:
+            self._set_container(parent_container)
         if subtype is not None:
             self.set_subtype(subtype)
         if owners is not None:
@@ -116,52 +208,47 @@ class Chart(
             self.set_terms(terms)
         if domain is not None:
             self.set_domain(domain)
-        if last_modified is not None:
-            self.set_last_modified(last_modified)
-        if input_datasets is not None:
-            self.set_input_datasets(input_datasets)
-        if description is not None:
-            self.set_description(description)
-        if display_name is not None:
-            self.set_display_name(display_name)
-
-    @classmethod
-    def _new_from_graph(cls, urn: Urn, current_aspects: models.AspectBag) -> Self:
-        assert isinstance(urn, ChartUrn)
-        entity = cls(
-            platform=urn.dashboard_tool,
-            name=urn.chart_id,
-        )
-        return entity._init_from_graph(current_aspects)
 
     @property
     def urn(self) -> ChartUrn:
         assert isinstance(self._urn, ChartUrn)
         return self._urn
 
-    def _ensure_chart_props(self) -> models.ChartInfoClass:
+    def _ensure_chart_props(
+        self, display_name: Optional[str] = None
+    ) -> models.ChartInfoClass:
         """Ensure chart properties exist, using a safer approach."""
         return self._setdefault_aspect(
             models.ChartInfoClass(
-                title=self.urn.chart_id,
+                title=display_name or self.urn.chart_id,
                 description="",
                 lastModified=models.ChangeAuditStampsClass(),
             )
         )
 
+    def _get_audit_stamps(self) -> models.ChangeAuditStampsClass:
+        """Get the audit stamps from the chart properties."""
+        return self._ensure_chart_props().lastModified
+
+    def _set_audit_stamps(self, audit_stamps: models.ChangeAuditStampsClass) -> None:
+        """Set the audit stamps on the chart properties."""
+        self._ensure_chart_props().lastModified = audit_stamps
+
     @property
     def name(self) -> str:
         """Get the name of the chart."""
         return self.urn.chart_id
 
     @property
+    @deprecated("Use display_name instead", version="1.2.0.7")
     def title(self) -> str:
-        """Get the title of the chart."""
-        return self._ensure_chart_props().title
+        """Get the display name of the chart."""
+        return self.display_name
 
+    @deprecated("Use set_display_name instead", version="1.2.0.7")
     def set_title(self, title: str) -> None:
-        """Set the title of the chart."""
-        self._ensure_chart_props().title = title
+        """Set the display name of the chart."""
+        self.set_display_name(title)
 
     @property
     def description(self) -> Optional[str]:
@@ -173,13 +260,13 @@ class Chart(
         self._ensure_chart_props().description = description
 
     @property
-    def display_name(self) -> Optional[str]:
+    def display_name(self) -> str:
         """Get the display name of the chart."""
-        return self.title
+        return self._ensure_chart_props().title
 
     def set_display_name(self, display_name: str) -> None:
         """Set the display name of the chart."""
-        self.set_title(display_name)
+        self._ensure_chart_props().title = display_name
 
     @property
     def external_url(self) -> Optional[str]:
@@ -208,24 +295,6 @@ class Chart(
         """Set the custom properties of the chart."""
         self._ensure_chart_props().customProperties = custom_properties
 
-    @property
-    def last_modified(self) -> Optional[datetime]:
-        """Get the last modification timestamp of the chart."""
-        last_modified_time = self._ensure_chart_props().lastModified.lastModified.time
-        if not last_modified_time:
-            return None
-        return datetime.fromtimestamp(last_modified_time)
-
-    def set_last_modified(self, last_modified: datetime) -> None:
-        """Set the last modification timestamp of the chart."""
-        chart_props = self._ensure_chart_props()
-        chart_props.lastModified = models.ChangeAuditStampsClass(
-            lastModified=models.AuditStampClass(
-                time=int(last_modified.timestamp()),
-                actor="urn:li:corpuser:datahub",
-            )
-        )
-
     @property
     def last_refreshed(self) -> Optional[datetime]:
         """Get the last refresh timestamp of the chart."""
@@ -250,9 +319,11 @@ class Chart(
     def set_chart_type(self, chart_type: Union[str, models.ChartTypeClass]) -> None:
         """Set the type of the chart."""
         if isinstance(chart_type, str):
-            assert chart_type in get_enum_options(models.ChartTypeClass), (
-                f"Invalid chart type: {chart_type}"
-            )
+            chart_type_options = get_enum_options(models.ChartTypeClass)
+            if chart_type not in chart_type_options:
+                raise ValueError(
+                    f"Invalid chart type: {chart_type}; valid types are {chart_type_options}"
+                )
         self._ensure_chart_props().type = chart_type
 
     @property
@@ -277,7 +348,7 @@ class Chart(
         return [DatasetUrn.from_string(input_urn) for input_urn in (props.inputs or [])]
 
     def set_input_datasets(
-        self, input_datasets: List[Union[DatasetUrnOrStr, Dataset]]
+        self, input_datasets: Sequence[Union[DatasetUrnOrStr, Dataset]]
     ) -> None:
         """Set the input datasets of the chart."""
         # Convert all inputs to strings
